:scenariouncertainty
:population
:geography
:socioeconomic
:emissions
:climateco2cycle
:climatech4cycle
:climaten2ocycle
:climatesf6cycle
:climateforcing
:climatedynamics
:biodiversity
:climateregional
:ocean
:impactagriculture
:impactbiodiversity
:impactcardiovascularrespiratory
:impactcooling
:impactdiarrhoea
:impactextratropicalstorms
:impactforests
:impactheating
:impactvectorbornediseases
:impacttropicalstorms
:vslvmorb
:impactdeathmorbidity
:impactwaterresources
:impactsealevelrise
:impactaggregation
